//
//  EmojiArtModel.swift
//  EmojiArt
//
//  Created by Sameh Fakhouri on 11/2/21.
//

import Foundation

struct EmojiArtModel: Codable {
    var background = Background.blank
    var emojis = [Emoji]()
    

    struct Emoji: Identifiable, Hashable, Codable {
        let text: String
        var x: Int // offset from the center
        var y: Int // offset from the center
        var size: Int
        let id: Int

        fileprivate init(text: String,
                         x: Int,
                         y: Int,
                         size: Int,
                         id: Int) {
            self.text = text
            self.x = x
            self.y = y
            self.size = size
            self.id = id
        }
    }
    
    func json() throws -> Data {
        return try JSONEncoder().encode(self)
    }
    
    init(json: Data) throws {
        let thisFunction = "\(String(describing: self)).\(#function)"
        print("\n\(thisFunction) json = \(String(data: json, encoding: .utf8) ?? "nil")")
        self = try JSONDecoder().decode(EmojiArtModel.self,
                                        from: json)
        print("\n\(thisFunction) JSONDecoder success!!!!")
    }
    
    init(url: URL) throws {
        let data = try Data(contentsOf: url)
        self = try EmojiArtModel(json: data)
    }
    
    init() {}

    private var uniqueEmojiId = 0
    
    mutating func addEmoji(_ text: String,
                           at location: (x: Int, y: Int),
                           size: Int) {
        uniqueEmojiId += 1
        emojis.append(Emoji(text: text,
                            x: location.x,
                            y: location.y,
                            size: size,
                            id: uniqueEmojiId))
    }
}
